#!/bin/bash 
# the following should work 
set -x

whiptail --msgbox 'hoge a You are a normal test' 10 20
whiptail --msgbox 'hoge a You are a normal test' 10 20
whiptail --msgbox ha 1 4
whiptail --msgbox ha 1 5

